from colorama import Fore, Back, Style
import shutil
import datetime


def line(
    info: str = None,
    width: int = 80,
    char: str = "-",
    color: str = "magenta",
    align: int = 1,
    margin: tuple = (1, 1),
    *args,
):

    columns, _ = shutil.get_terminal_size()
    sup_limit = columns
    if width == 0 or width > columns:
        width = sup_limit
    if align < 0:
        info = "" if info is None else info
        align = (
            width + align - len(info) - sum(margin)
        ) % width
    else:
        align = align % width

    if info is None:
        color_code = getattr(Fore, color.upper())
        return str(
            color_code + str(char) * width + Fore.RESET
        )
    sub_limit = len(info) + sum(margin) + align
    if width < sub_limit:
        width = sub_limit
    else:
        color_code = getattr(Fore, color.upper())
        return "".join(
            [
                color_code,
                char * align,
                " " * margin[0],
                info,
                " " * margin[1],
                char
                * (
                    width - sum(margin) - len(info) - align
                ),
                Fore.RESET,
            ]
        )


def dateline():
    line(
        datetime.datetime.now().strftime(
            "%d %b %Y %H:%M:%S"
        )
    )



import unittest
from seperator.lines import line


class TestLinesFunctions(unittest.TestCase):
    def test_empty_call(self):
        self.assertEqual(line(), "\x1b[35m" + 80 * "-")

    def test_info(self):
        self.assertEqual(
            line("INFORMATIVE TEXT"),
            "\x1b[35m"
            + "-"
            + " "
            + "INFORMATIVE TEXT"
            + " "
            + "-"
            * (80 - (2 + 1 + len("INFORMATIVE TEXT"))),
        )

    def test_color(self):
        self.assertEqual(
            line(color="ReD"), "\x1b[31m" + 80 * "-"
        )

    def test_align(self):
        self.assertEqual(
            line("INFORMATIVE TEXT", align=-1),
            "\x1b[35m"
            + "-"
            * (80 - (2 + 1 + len("INFORMATIVE TEXT")))
            + " "
            + "INFORMATIVE TEXT"
            + " "
            + "-",
        )

    def test_margin(self):
        self.assertEqual(
            line("INFORMATIVE TEXT", margin=(2, 3)),
            "\x1b[35m"
            + "-"
            + " " * 2
            + "INFORMATIVE TEXT"
            + " " * 3
            + "-"
            * (80 - (5 + 1 + len("INFORMATIVE TEXT"))),
        )

    def test_char(self):
        self.assertEqual(
            line(char="#"), "\x1b[35m" + 80 * "#"
        )


if __name__ == "__main__":
    unittest.main()
